@@ -54,8 +54,6 @@ void METHOD_NAME(X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, int byrow, ANS_C_TYP
     kk_prev = 0;
     for (jj=1; jj < ncol; jj++) {
       for (ii=0; ii < nrow; ii++) {
-        if (kk % 1000 == 0)
-          R_CheckUserInterrupt();
 #if ANS_TYPE == 'i'
         if (oks[ii]) {
           /* Missing value? */
@@ -82,6 +80,8 @@ void METHOD_NAME(X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, int byrow, ANS_C_TYP
 
         kk++;        
         kk_prev++;        
+
+        R_CHECK_USER_INTERRUPT(kk);
       } /* for (ii ...) */
     } /* for (jj ...) */
   } else {
@@ -92,8 +92,6 @@ void METHOD_NAME(X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, int byrow, ANS_C_TYP
       ok = 1;
 #endif
       for (ii=0; ii < nrow; ii++) {
-        if (kk % 1000 == 0)
-          R_CheckUserInterrupt();
 #if ANS_TYPE == 'i'
         if (ok) {
           /* Missing value? */
@@ -120,6 +118,8 @@ void METHOD_NAME(X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, int byrow, ANS_C_TYP
 #endif
 
         kk++;        
+
+        R_CHECK_USER_INTERRUPT(kk);
       } /* for (ii ...) */
     } /* for (jj ...) */
   } /* if (byrow) */
