@@ -8,7 +8,7 @@ data <- data.frame(
   integer=1:4,
   double=seq(from=1.0, to=4.0, by=1.0),
   complex=seq(from=1.0, to=4.0, by=1.0) + 1.0i,
-  character=letters[1:4]
+  character=I(letters[1:4])
 )
 
 modes <- names(data)
